var win = Titanium.UI.createWindow({  
    backgroundColor:'#fff'
});

var view = Ti.UI.createView({
	borderWidth: 1,
	left: 10,
	top: 10,
	width: 57,
	height: 57
});
win.add(view);
win.add(Ti.UI.createLabel({
	text: "Remote",
	top: 70,
	left: 10,
	width: 57,
	textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER
}));

var view2 = Ti.UI.createView({
	borderWidth: 1,
	left: 75,
	top: 10,
	width: 57,
	height: 57
});
win.add(view2);
win.add(Ti.UI.createLabel({
	text: "Local",
	top: 70,
	left: 75,
	width: 57,
	textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER
}));

win.add(Ti.UI.createLabel({
	text: "Check console for output",
	top: 150,
	left: 5,
	right: 5
}));

win.open();

var fs = Ti.Filesystem;

function ls() {
	var f = fs.getFile.apply(null, arguments);
	var listing = f.getDirectoryListing();
	Ti.API.log("****************************************");
	Ti.API.log("Found " + listing.length + " file" + (listing.length == 1 ? '' : 's'));
	for (var i = 0; i < listing.length; i++) {
		Ti.API.log(listing[i]);
	}
}

function runTest(name, test) {
	var r = 0, logbuffer = [], done = 0;
	try {
		r = test(function(s) {
			if (done) {
				console[r ? "log" : "error"]("[" + (r ? "PASS" : "FAIL") + "] " + s);
			} else {
				logbuffer.push(s);
			}
		});
	} catch (ex) {
		logbuffer.push(ex.toString());
	}
	console.log("[TEST] " + (/\.\.\.$/.test(name) ? name : name) + "...");
	logbuffer.length || console[r ? "log" : "error"](r ? "[PASS] Test passed" : "[FAIL] Test failed");
	logbuffer.forEach(function(s) {
		console[r ? "log" : "error"]("[" + (r ? "PASS" : "FAIL") + "] " + s);
	});
	done = 1;
}

// reset the playing field
if (Ti.Platform.osname == "mobileweb") {
	Ti.API.log("Resetting the localStorage");
	for (var i = 0; i < localStorage.length;) {
		var key = localStorage.key(i++);
		if (key.indexOf("ti:fs") == 0 && key != "ti:fs:meta:appdata://" && key != "ti:fs:meta:tmp://") {
			localStorage.removeItem(key);
			i = 0;
		}
	}
}

// paths
runTest("Filesystem Paths", function(log) {
	log("Application Data Directory: " + fs.applicationDataDirectory);
	log("Resource Directory: " + fs.resourcesDirectory);
	log("Temp Directory: " + fs.tempDirectory);
	log("External Storage Present? " + fs.isExternalStoragePresent());
	return 1;
});

// exists tests
runTest("Checking if \"/test.txt\" exists", function(log) {
	var file = fs.getFile("test.txt");
	if (file.exists()) {
		log("Good! " + file.nativePath + " exists");
		return 1;
	}
	log(file.nativePath + " does not exist");
});

runTest("Checking if \"/test2.txt\" does not exist", function(log) {
	var file = fs.getFile("test2.txt");
	if (!file.exists()) {
		log("Good! " + file.nativePath + " does not exist");
		return 1;
	}
	log(file.nativePath + " exists");
});

runTest("Checking if \"/titanium\" exists", function(log) {
	var file = fs.getFile("titanium");
	if (file.exists()) {
		log("Good! " + file.nativePath + " exists");
		return 1;
	}
	log(file.nativePath + " does not exist");
});

runTest("Checking if \"appdata://test.txt\" does not exist", function(log) {
	var file = fs.getFile("appdata://test.txt");
	if (!file.exists()) {
		log("Good! " + file.nativePath + " does not exist");
		return 1;
	}
	log(file.nativePath + " exists");
});

runTest("Checking if \"tmp://test.txt\" does not exist", function(log) {
	var file = fs.getFile("tmp://test.txt");
	if (!file.exists()) {
		log("Good! " + file.nativePath + " does not exist");
		return 1;
	}
	log(file.nativePath + " exists");
});

runTest("Checking invaild url \"..\"", function(log) {
	try {
		var file = fs.getFile("..");
	} catch (ex) {
		log("Good! \"..\" was an invalid url");
		return 1;
	}
});

// creation tests
runTest("Creating file \"appc.txt\", but should fail because resource dir is readonly", function(log) {
	var file = fs.getFile("appc.txt");
	try {
		if (file.createFile()) {
			log("Created " + file.nativePath + " in a readonly filesystem!");
			return 0;
		}
	} catch (ex) {}
	log("Good! Couldn't create " + file.nativePath);
	return 1;
});

runTest("Creating directory \"appc\", but should fail because resource dir is readonly", function(log) {
	var file = fs.getFile("appc");
	try {
		if (file.createDirectory()) {
			log("Created " + file.nativePath + " in a readonly filesystem!");
			return 0;
		}
	} catch (ex) {}
	log("Good! Couldn't create " + file.nativePath);
	return 1;
});

runTest("Creating file empty file \"appdata://empty.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "empty.txt");
	if (file.createFile()) {
		log("Good! Created " + file.nativePath);
		var check = fs.getFile(fs.applicationDataDirectory, "empty.txt");
		if (check.exists()) {
			log("Confirmed " + file.nativePath + " was created");
			return 1;
		}
	}
	log("Failed to create " + file.nativePath);
});

runTest("Creating file non-empty file \"appdata://hello.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "hello.txt");
	if (file.write("Hello world!")) {
		log("Good! Created " + file.nativePath + " and wrote 'Hello World' to it");
		var check = fs.getFile(fs.applicationDataDirectory, "hello.txt");
		if (check.exists()) {
			log("Confirmed " + file.nativePath + " was created");
			return 1;
		}
	}
	log("Failed to create " + file.nativePath);
});

runTest("Creating directory \"appdata://foo\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "foo");
	if (file.createDirectory()) {
		log("Good! Created " + file.nativePath);
		var check = fs.getFile(fs.applicationDataDirectory, "foo");
		if (check.exists()) {
			log("Confirmed " + file.nativePath + " was created");
			return 1;
		}
	}
	log("Failed to create " + file.nativePath);
});

runTest("Creating directory \"appdata://howdy\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "howdy");
	if (file.createDirectory()) {
		log("Good! Created " + file.nativePath);
		var check = fs.getFile(fs.applicationDataDirectory, "howdy");
		if (check.exists()) {
			log("Confirmed " + file.nativePath + " was created");
			return 1;
		}
	}
	log("Failed to create " + file.nativePath);
});

// stat tests
runTest("Getting file info for \"appdata://hello.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "hello.txt");
	if (file.exists()) {
		if (file.name != "hello.txt") {
			log("Name: " + file.name + ", expected \"hello.txt\"");
			return 0;
		}
		log("Name: " + file.name);

		if (file.isFile() != true) {
			log("Is File? " + file.isFile() + ", expected true");
			return 0;
		}
		log("Is File? " + file.isFile());

		if (file.isDirectory() != false) {
			log("Is Directory? " + file.isDirectory() + ", expected false");
			return 0;
		}
		log("Is Directory? " + file.isDirectory());

		if (file.executable != false) {
			log("Executable: " + file.executable + ", expected false");
			return 0;
		}
		log("Executable: " + file.executable);

		if (file.readonly != false) {
			log("Readonly: " + file.readonly + ", expected false");
			return 0;
		}
		log("Readonly: " + file.readonly);

		if (file.size != 12) {
			log("Size: " + file.size + ", expected 12");
			return 0;
		}
		log("Size: " + file.size);

		if (file.symbolicLink != false) {
			log("Symbolic Link: " + file.symbolicLink + ", expected false");
			return 0;
		}
		log("Symbolic Link: " + file.symbolicLink);

		if (file.hidden != false) {
			log("Hidden: " + file.hidden + ", expected false");
			return 0;
		}
		log("Hidden: " + file.hidden);

		if (file.nativePath != "appdata://hello.txt") {
			log("Native Path: " + file.nativePath + ", expected \"appdata://hello.txt\"");
			return 0;
		}
		log("Native Path: " + file.nativePath);

		if (!file.parent) {
			log("Parent is null, expected parent appdata:// to exist");
			return 0;
		}
		if (file.parent.nativePath != "appdata://") {
			log("Parent: " + file.parent.nativePath + ", expected \"appdata://\"");
			return 0;
		}
		log("Parent: " + file.parent.nativePath);

		if (file.writable != true) {
			log("Writable: " + file.writable + ", expected true");
			return 0;
		}
		log("Writable: " + file.writable);

		log("Creation Timestamp: " + (new Date(file.createTimestamp())));
		log("Modification Timestamp: " + (new Date(file.modificationTimestamp())));

		if (file.extension() != "txt") {
			log("Extension: " + file.extension() + ", expected \"txt\"");
			return 0;
		}
		log("Extension: " + file.extension());

		if (file.resolve() != "appdata://hello.txt") {
			log("Resolved Path: " + file.resolve() + ", expected \"appdata://hello.txt\"");
			return 0;
		}
		log("Resolved Path: " + file.resolve());

		return 1;
	}
	log("File \"" + file.nativePath + "\" does not exist!");
});

// read tests
runTest("Reading file that exists \"appdata://hello.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "hello.txt");
	if (file.exists()) {
		var blob = file.read();
		if (!blob) {
			log("File was empty!");
			return 0;
		}
		if (blob.text != "Hello world!") {
			log("Contents: " + blob.text + ", expected \"Hello world!\"");
			return 0;
		}
		log("Contents: " + blob.text);
		return 1;
	}
	log("File \"" + file.nativePath + "\" does not exist!");
});

runTest("Try to read a directory as if it was a file \"appdata://foo\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "foo");
	if (file.exists()) {
		var blob = file.read();
		if (blob) {
			log("Blob was not null, expected null");
			return 0;
		}
		log("Good! Blob was null");
		return 1;
	}
	log("Directory \"" + file.nativePath + "\" does not exist!");
});

// write tests
runTest("Writing to readonly file \"/error.txt\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "error.txt");
	if (!file.write("This should not work")) {
		log("Good! Unable to write error.txt file");
		return 1;
	}
	log("Was able to write \"/error.txt\" file, but it should have failed");
});

runTest("Try to write to a file that is already a directory \"appdata://foo\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "foo");
	if (!file.write("This should not work")) {
		log("Good! Unable to write \"appdata://foo\" file");
		return 1;
	}
	log("Was able to write \"appdata://foo\" file, but it should have failed");
});

runTest("Write new file into subdirectory \"appdata://foo/bar.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "foo", "bar.txt");
	if (file.write("Titanium rocks")) {
		log("Good! Wrote \"appdata://foo/bar.txt\" file");
		return 1;
	}
	log("Unable to write file \"appdata://foo/bar.txt\"");
});

// space available
runTest("Testing available space", function(log) {
	log("Space Available: " + fs.getFile().spaceAvailable());
	return 1;
});

// rename tests
runTest("Renaming readonly file \"/test.txt\" to \"/test2.txt\", but should fail", function(log) {
	var file = fs.getFile("test.txt");
	if (!file.rename("test2.txt")) {
		log("Good! Unable to rename \"/test.txt\" file");
		return 1;
	}
	log("Renamed readonly file \"/test.txt\", but should have failed");
});

runTest("Renaming file \"appdata://hello.txt\" to \"appdata://helloworld.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "hello.txt");
	if (file.rename("helloworld.txt")) {
		log("Good! Renamed file \"appdata://hello.txt\" to \"appdata://helloworld.txt\"");
		return 1;
	}
	log("Unable to rename file \"appdata://hello.txt\"");
});

runTest("Renaming directory \"appdata://foo\" to \"appdata://baz\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "foo");
	if (file.rename("baz")) {
		log("Good! Renamed \"appdata://foo\" to \"appdata://baz\"");
		return 1;
	}
	log("Unable to rename directory \"appdata://foo\"");
});

// temp tests
runTest("Creating a temp file", function(log) {
	var file = fs.createTempFile();
	if (file.exists()) {
		log("Good! Created temp file \"" + file.nativePath + "\"");
		if (file.isFile()) {
			log("Good! Confirmed temp file is a file");
			return 1;
		}
		log("Temp file is not a file!");
	}
	log("Unable to create temp file");
});

runTest("Creating a temp directory", function(log) {
	var file = fs.createTempDirectory();
	if (file.exists()) {
		log("Good! Created temp directory \"" + file.nativePath + "\"");
		if (file.isDirectory()) {
			log("Good! Confirmed temp directory is a directory");
			return 1;
		}
		log("Temp directory is not a directory!");
	}
	log("Unable to create temp directory");
});

// move tests
runTest("Moving readonly file \"/test.txt\" to \"appdata://\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "test.txt");
	if (!file.move(fs.applicationDataDirectory)) {
		log("Good! Failed to move a readonly file");
		return 1;
	}
	log("Moved a readonly file!");
});

runTest("Moving readonly directory \"/titanium\" to \"appdata://\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "titanium");
	if (!file.move(fs.applicationDataDirectory)) {
		log("Good! Failed to move a readonly directory");
		return 1;
	}
	log("Moved a readonly directory!");
});

runTest("Moving file \"appdata://helloworld.txt\" to readonly directory \"/titanium\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "helloworld.txt");
	if (!file.move(fs.resourcesDirectory, "titanium")) {
		log("Good! Failed to move file to readonly directory");
		return 1;
	}
	log("Moved a file to a readonly directory!");
});

runTest("Moving file \"appdata://helloworld.txt\" to \"appdata://howdy\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "helloworld.txt");
	if (file.move(fs.applicationDataDirectory, "howdy")) {
		log("Good! Moved \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to move \"" + file.nativePath + "\"");
});

runTest("Moving directory \"appdata://howdy\" to \"appdata://baz\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "howdy");
	if (file.move(fs.applicationDataDirectory, "baz")) {
		log("Good! Moved \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to move \"" + file.nativePath + "\"");
});

// copy tests
runTest("Copying file \"appdata://baz/bar.txt\" to readonly directory \"/\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "baz", "bar.txt");
	if (!file.copy(fs.resourcesDirectory)) {
		log("Good! Failed to copy file to a readonly directory");
		return 1;
	}
	log("Copied a readonly file!");
});

runTest("Copying file \"appdata://baz/bar.txt\" to \"appdata://titanium\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "baz", "bar.txt");
	if (file.copy(fs.applicationDataDirectory, "titanium")) {
		log("Good! Copied \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to copy \"" + file.nativePath + "\"");
});

// append tests
runTest("Appending to \"appdata://baz/bar.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "baz", "bar.txt");
	if (file.append(" the house")) {
		log("Good! Appended to file");
		return 1;
	}
	log("Failed to append to \"" + file.nativePath + "\"");
});

runTest("Appending to readonly \"/test.txt\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "test.txt");
	if (!file.append("This should not work")) {
		log("Good! Unable to append to readonly file");
		return 1;
	}
	log("Was able to append to readonly file!");
});

runTest("Appending to directory \"appdata://baz\" instead of file", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "baz");
	if (!file.append("This should not work")) {
		log("Good! Unable to append to directory");
		return 1;
	}
	log("Was able to append to directory!");
});

// more copy tests
runTest("Copying file \"appdata://baz/bar.txt\" to \"appdata://titanium\" again", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "baz", "bar.txt");
	if (file.copy(fs.applicationDataDirectory, "titanium")) {
		log("Good! Copied and overwrote \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to copy and override \"" + file.nativePath + "\"");
});

runTest("Copying readonly file \"/test.txt\" to \"appdata://titanium\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "test.txt");
	if (file.copy(fs.applicationDataDirectory, "titanium")) {
		log("Good! Copied readonly file \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to copy readonly file \"" + file.nativePath + "\"");
});

runTest("Copying directory \"appdata://titanium\" to \"appdata://titanium2\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium");
	if (file.copy(fs.applicationDataDirectory, "titanium2")) {
		log("Good! Copied directory \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to copy directory \"" + file.nativePath + "\"");
});

runTest("Copying readonly directory \"appdata://example\" to \"appdata://\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "example");
	if (file.copy(fs.applicationDataDirectory)) {
		log("Good! Copied readonly directory \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to copy directory \"" + file.nativePath + "\"");
});

// delete tests
runTest("Deleting readonly file \"/test.txt\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "test.txt");
	if (!file.deleteFile()) {
		log("Good! Unable to delete readonly file");
		return 1;
	}
	log("Deleted readonly file!");
});

runTest("Deleting file \"appdata://titanium2/titanium/test.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium2", "titanium", "test.txt");
	if (file.deleteFile()) {
		log("Good! Deleted \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to delete file \"" + file.nativePath + "\"!");
});

runTest("Deleting non-existent file \"appdata://error.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "error.txt");
	if (!file.deleteFile()) {
		log("Good! Couldn't delete non-existent file \"" + file.nativePath + "\"");
		return 1;
	}
	log("Deleted non-existent file \"" + file.nativePath + "\"!");
});

runTest("Deleting non-empty directory \"appdata://titanium2/titanium\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium2", "titanium");
	if (!file.deleteDirectory()) {
		log("Good! Couldn't delete non-empty directory \"" + file.nativePath + "\"");
		return 1;
	}
	log("Deleted non-empty file \"" + file.nativePath + "\"!");
});

runTest("Recursively deleting non-empty directory \"appdata://titanium2/titanium\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium2", "titanium");
	if (file.deleteDirectory(true)) {
		log("Good! Recursively deleted directory \"" + file.nativePath + "\"");
		return 1;
	}
	log("Unable to recursively delete directory \"" + file.nativePath + "\"!");
});

// directory listing tests
runTest("Listing directory \"appdata://\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory),
		listing = file.getDirectoryListing();
	if (listing.length == 6) {
		log("Good! Found " + listing.length + " files in \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to get correct number of files in \"" + file.nativePath + "\", got " + listing.length + ", expected 6");
});

runTest("Listing non-existent directory \"appdata://no-exist\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "no-exist"),
		listing = file.getDirectoryListing();
	if (listing.length == 0) {
		log("Good! Found " + listing.length + " files in \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to get correct number of files in \"" + file.nativePath + "\", got " + listing.length + ", expected 0");
});

runTest("Listing file instead directory \"appdata://test.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "test.txt"),
		listing = file.getDirectoryListing();
	if (listing.length == 0) {
		log("Good! Found " + listing.length + " files in \"" + file.nativePath + "\"");
		return 1;
	}
	log("Failed to get correct number of files in \"" + file.nativePath + "\", got " + listing.length + ", expected 0");
});

// blob tests
runTest("Getting blob for \"appdata://test.txt\"", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "test.txt"),
		blob = file.read();
	if (blob) {
		log("Blob Mime Type: " + blob.mimeType);
		log("Blob Length: " + blob.length);
		log("Blob File: " + blob.file.nativePath);
		log("Blob Contents: " + blob.text);
		return 1;
	}
	log("Failed to get blob for \"" + file.nativePath + "\"");
});

runTest("Getting image blob \"/apple-touch-icon-precomposed.png\"", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "apple-touch-icon-precomposed.png");
	if (file.exists()) {
		var blob = file.read();
		log("Blob Mime Type: " + blob.mimeType);
		log("Blob File: " + blob.file.nativePath);
		log("Blob Size: " + blob.size);
		log("Blob Width: " + blob.width);
		log("Blob Height: " + blob.height);
		if (blob.width == 0) {
			log("Note: blob image is not loaded, so we're going to do a setTimeout to see the width/height... watch below for out-of-order log message with the image size");
			setTimeout(function() {
				log("Blob Width/Height: " + blob.width + " x " + blob.height);
			}, 250);
		}
		log("Blob toString(): " + blob.toString());
		return 1;
	}
	log("\"" + file.nativePath + "\" does not exist!");
});

runTest("Copy image blob \"/apple-touch-icon-precomposed.png\" to \"appdata://titanium.png\"", function(log) {
	var src = fs.getFile(fs.resourcesDirectory, "apple-touch-icon-precomposed.png");
	if (src.exists()) {
		var dest = fs.getFile(fs.applicationDataDirectory, "titanium.png");
		dest.write(src);
		log("Copied \"" + src.nativePath + "\" to \"" + dest.nativePath + "\"");
		return 1;
	}
	log("\"" + src.nativePath + "\" does not exist!");
});

// background image tests
runTest("Setting remote image blob \"/apple-touch-icon-precomposed.png\" as view background", function(log) {
	var file = fs.getFile(fs.resourcesDirectory, "apple-touch-icon-precomposed.png");
	if (file.exists()) {
		view.backgroundImage = file.read();
		log("Set view background!");
		return 1;
	}
	log("\"" + file.nativePath + "\" does not exist!");
});

runTest("Setting local image blob \"appdata://apple-touch-icon-precomposed.png\" as view background", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium.png");
	if (file.exists()) {
		view2.backgroundImage = file.read();
		log("Set view background!");
		return 1;
	}
	log("\"" + file.nativePath + "\" does not exist!");
});

// open, stream, buffer tests
runTest("Opening a file stream for file \"appdata://titanium/bar.txt\" method 1", function(log) {
	var file = fs.getFile(fs.applicationDataDirectory, "titanium", "bar.txt"),
		buffer = Ti.createBuffer(),
		stream = file.open(Ti.Filesystem.MODE_APPEND);
	if (stream) {
		stream.read(buffer, 0, 14);
		log("Read first 14 bytes: \"" + buffer.value + "\"");
		return 1;
	}
	log("File stream was null!");
});

runTest("Opening a file stream for a non-existent file \"appdata://error.txt\" method 2", function(log) {
	var stream = fs.openStream(Ti.Filesystem.MODE_APPEND, fs.applicationDataDirectory, "error.txt"),
		buffer = Ti.createBuffer();
	if (!stream) {
		log("Good! File stream was null!");
		return 1;
	}
	log("Was able to open a file stream to a non-existent file!");
});

runTest("Opening a file stream for file \"appdata://titanium/bar.txt\" method 2", function(log) {
	var stream = fs.openStream(Ti.Filesystem.MODE_APPEND, fs.applicationDataDirectory, "titanium", "bar.txt"),
		buffer = Ti.createBuffer();
	if (stream) {
		stream.read(buffer, 0, 14);
		log("Read first 14 bytes: \"" + buffer.value + "\"");
		return 1;
	}
	log("File stream was null!");
});

Ti.API.log("Tests complete");
Ti.API.log("Use ls() function to browse directories:");
ls("/");
